@@ -409,8 +409,8 @@ static char *parser_get_next_value(char *line, char **end, icalvalue_kind kind)
                 continue;
             }
         }
-        /* ignore all , for query value. select dtstart, dtend etc ... */
-        else if (kind == ICAL_QUERY_VALUE) {
+        /* ignore all commas for query and x values. select dtstart, dtend etc ... */
+        else if (kind == ICAL_QUERY_VALUE || kind == ICAL_X_VALUE) {
             if (next != 0) {
                 p = next + 1;
                 continue;
@@ -604,7 +604,7 @@ static void insert_error(icalcomponent *comp, const char *text,
 
     icalcomponent_add_property(
         comp,
-        icalproperty_vanew_xlicerror(temp, icalparameter_new_xlicerrortype(type), 0));
+        icalproperty_vanew_xlicerror(temp, icalparameter_new_xlicerrortype(type), (void *)0));
 }
 
 static int line_is_blank(char *line)
@@ -626,6 +626,7 @@ icalcomponent *icalparser_parse(icalparser *parser,
                                 icalparser_line_gen_func line_gen_func)
 {
     char *line;
+    unsigned int cnt = 0;
     icalcomponent *c = 0;
     icalcomponent *root = 0;
     icalerrorstate es = icalerror_get_error_state(ICAL_MALFORMEDDATA_ERROR);
@@ -636,6 +637,7 @@ icalcomponent *icalparser_parse(icalparser *parser,
     icalerror_set_error_state(ICAL_MALFORMEDDATA_ERROR, ICAL_ERROR_NONFATAL);
 
     do {
+        cnt++;
         line = icalparser_get_line(parser, line_gen_func);
 
         if ((c = icalparser_add_line(parser, line)) != 0) {
@@ -675,7 +677,7 @@ icalcomponent *icalparser_parse(icalparser *parser,
             icalmemory_free_buffer(line);
             cont = 1;
         }
-    } while (cont);
+    } while (cont && cnt < TMP_BUF_SIZE);
 
     icalerror_set_error_state(ICAL_MALFORMEDDATA_ERROR, es);
 
